        function getT(rr,cc){
       if(rr==3 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260516 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==3 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260516 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>47</strong> miembros: 28 <strong>control</strong><br>0,2,3,4,5,7,9,10,12,14,17,20,21,24,25,27,29,30,32,33,34,37,43,44,47,48,49,50';}
       if(rr==3 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260516 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>28</strong> miembros: 23 <br>1,6,8,11,13,15,16,18,19,22,23,26,28,31,35,36,38,39,40,41,42,45,46';}
       if(rr==17 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260516 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==17 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260516 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>47</strong> miembros: 28 <strong>control</strong><br>0,2,3,4,5,7,9,10,12,14,17,20,21,24,25,27,29,30,32,33,34,37,43,44,47,48,49,50';}
       if(rr==17 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 1 mm</strong><br><br><strong>20260516 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>28</strong> miembros: 23 <br>1,6,8,11,13,15,16,18,19,22,23,26,28,31,35,36,38,39,40,41,42,45,46';}
       if(rr==19 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260516 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==19 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260516 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>47</strong> miembros: 28 <strong>control</strong><br>0,2,3,4,5,7,9,10,12,14,17,20,21,24,25,27,29,30,32,33,34,37,43,44,47,48,49,50';}
       if(rr==19 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 2 mm</strong><br><br><strong>20260516 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>28</strong> miembros: 23 <br>1,6,8,11,13,15,16,18,19,22,23,26,28,31,35,36,38,39,40,41,42,45,46';}
       if(rr==20 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260516 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==20 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260516 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>47</strong> miembros: 28 <strong>control</strong><br>0,2,3,4,5,7,9,10,12,14,17,20,21,24,25,27,29,30,32,33,34,37,43,44,47,48,49,50';}
       if(rr==20 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 5 mm</strong><br><br><strong>20260516 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>28</strong> miembros: 23 <br>1,6,8,11,13,15,16,18,19,22,23,26,28,31,35,36,38,39,40,41,42,45,46';}
       if(rr==21 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260516 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==21 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260516 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>47</strong> miembros: 28 <strong>control</strong><br>0,2,3,4,5,7,9,10,12,14,17,20,21,24,25,27,29,30,32,33,34,37,43,44,47,48,49,50';}
       if(rr==21 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 10 mm</strong><br><br><strong>20260516 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>28</strong> miembros: 23 <br>1,6,8,11,13,15,16,18,19,22,23,26,28,31,35,36,38,39,40,41,42,45,46';}
       if(rr==22 && cc==0){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260516 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==22 && cc==1){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260516 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>47</strong> miembros: 28 <strong>control</strong><br>0,2,3,4,5,7,9,10,12,14,17,20,21,24,25,27,29,30,32,33,34,37,43,44,47,48,49,50';}
       if(rr==22 && cc==2){return '<strong>Probabilidad de precipitacion de 0 a 24 UTC superior a 20 mm</strong><br><br><strong>20260516 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>28</strong> miembros: 23 <br>1,6,8,11,13,15,16,18,19,22,23,26,28,31,35,36,38,39,40,41,42,45,46';}
}
