        function getT(rr,cc){
       if(rr==6 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260516 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==6 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260516 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>47</strong> miembros: 28 <strong>control</strong><br>0,2,3,4,5,7,9,10,12,14,17,20,21,24,25,27,29,30,32,33,34,37,43,44,47,48,49,50';}
       if(rr==6 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260516 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>28</strong> miembros: 23 <br>1,6,8,11,13,15,16,18,19,22,23,26,28,31,35,36,38,39,40,41,42,45,46';}
       if(rr==29 && cc==0){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260516 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==29 && cc==1){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260516 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>47</strong> miembros: 28 <strong>control</strong><br>0,2,3,4,5,7,9,10,12,14,17,20,21,24,25,27,29,30,32,33,34,37,43,44,47,48,49,50';}
       if(rr==29 && cc==2){return '<strong>Probabilidad de racha maxima superior a 20 km/h (11 kt)</strong><br><br><strong>20260516 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>28</strong> miembros: 23 <br>1,6,8,11,13,15,16,18,19,22,23,26,28,31,35,36,38,39,40,41,42,45,46';}
       if(rr==30 && cc==0){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260516 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==30 && cc==1){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260516 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>47</strong> miembros: 28 <strong>control</strong><br>0,2,3,4,5,7,9,10,12,14,17,20,21,24,25,27,29,30,32,33,34,37,43,44,47,48,49,50';}
       if(rr==30 && cc==2){return '<strong>Probabilidad de racha maxima superior a 40 km/h (22 kt)</strong><br><br><strong>20260516 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>28</strong> miembros: 23 <br>1,6,8,11,13,15,16,18,19,22,23,26,28,31,35,36,38,39,40,41,42,45,46';}
       if(rr==31 && cc==0){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260516 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==31 && cc==1){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260516 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>47</strong> miembros: 28 <strong>control</strong><br>0,2,3,4,5,7,9,10,12,14,17,20,21,24,25,27,29,30,32,33,34,37,43,44,47,48,49,50';}
       if(rr==31 && cc==2){return '<strong>Probabilidad de racha maxima superior a 63 km/h (34 kt)</strong><br><br><strong>20260516 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>28</strong> miembros: 23 <br>1,6,8,11,13,15,16,18,19,22,23,26,28,31,35,36,38,39,40,41,42,45,46';}
       if(rr==32 && cc==0){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260516 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==32 && cc==1){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260516 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>47</strong> miembros: 28 <strong>control</strong><br>0,2,3,4,5,7,9,10,12,14,17,20,21,24,25,27,29,30,32,33,34,37,43,44,47,48,49,50';}
       if(rr==32 && cc==2){return '<strong>Probabilidad de racha maxima superior a 90 km/h (48 kt)</strong><br><br><strong>20260516 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>28</strong> miembros: 23 <br>1,6,8,11,13,15,16,18,19,22,23,26,28,31,35,36,38,39,40,41,42,45,46';}
       if(rr==33 && cc==0){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260516 a 00</strong> UTC HH+078 (rango:072-084)<br><strong>control +<br>EPS</strong>';}
       if(rr==33 && cc==1){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260516 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>1</strong> representante: <strong>47</strong> miembros: 28 <strong>control</strong><br>0,2,3,4,5,7,9,10,12,14,17,20,21,24,25,27,29,30,32,33,34,37,43,44,47,48,49,50';}
       if(rr==33 && cc==2){return '<strong>Probabilidad de racha maxima superior a 119 km/h (64 kt)</strong><br><br><strong>20260516 a 00</strong> UTC HH+078 (rango:072-084)<br>grupo: <strong>2</strong> representante: <strong>28</strong> miembros: 23 <br>1,6,8,11,13,15,16,18,19,22,23,26,28,31,35,36,38,39,40,41,42,45,46';}
}
